/* 	============================================================================
    Main Header File
   	========================================================================= */
#include <xc.h>
#include <stdint.h>

/* 	============================================================================
    Section: Macro Declarations and defines
   	========================================================================= */
#define _XTAL_FREQ          8000000


// Our counter has 10 states defined as follows:
#define 	Num_0 			'A'	//States enumeration. "Char"
#define 	Num_1 			'B'
#define 	Num_2 			'C'
#define 	Num_3 			'D'
#define 	Num_4 			'E'
#define 	Num_5 			'F'
#define 	Num_6 			'G'
#define 	Num_7 			'H'
#define 	Num_8 			'I'
#define 	Num_9 			'J'


/* 	============================================================================
	Section: Global variables  
  	========================================================================= */
// Even if variables are 'bit' type, we use uint8_t (char) to make them easy 
// to watch while debugging in Proteus .

uint8_t Var_CE;
uint8_t Var_TC10;
uint8_t Var_BCD_code; 

//Flag that will be set only when there is new information to print on the LCD
uint8_t Var_LCD_flag;	

uint8_t Var_CLK_flag; // Software flag to be set when INT0
        
// The state variable which will be updated ("asynchronously") every time that 
// "state_logic()" is executed. 
// This is the FSM memory equivalent to the state register in Chapter 2  
uint8_t current_state = Num_0;	



/* 	============================================================================
	Section: Function prototypes
   	========================================================================= */
// The three basic functions to organise the code to emulate a FSM
void init_system (void);         
char state_logic(void);
char output_logic(void);    

// The auxiliary functions to read/poll and write port pins and be able to
// organise the software variables, to make the main program hardware
// independent and compatible for many microcontrollers. 
void write_outputs (void);
void read_inputs(void);  